Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'src/dedicated/dedicated.h')
-rw-r--r--src/dedicated/dedicated.h36
1 files changed, 27 insertions, 9 deletions
diff --git a/src/dedicated/dedicated.h b/src/dedicated/dedicated.h
index 4691e91..4b1f584 100644
--- a/src/dedicated/dedicated.h
+++ b/src/dedicated/dedicated.h
@@ -1,19 +1,37 @@
/*
- server/server.h
+ dedicated/dedicated.h
This file is part of the Osirion project and is distributed under
the terms and conditions of the GNU General Public License version 2
*/
-#ifndef __INCLUDED_SERVER_H__
-#define __INCLUDED_SERVER_H__
+#ifndef __INCLUDED_DEDICATED_H__
+#define __INCLUDED_DEDICATED_H__
-/// contains classes and functions to run a dedicated server
-namespace server {
+#include "core/application.h"
-/// the server main loop
-void main(int count, char **arguments);
+/// contains classes and functions to run the dedicated server
+namespace dedicated {
+
+/// run the dedicated server
+void run(int count, char **arguments);
-} // namespace server
+/// server application implementation
+class Dedicated : public core::Application {
+public:
+ /// initialize the server Application
+ virtual void init(int count, char **arguments);
+
+ /// run the server Application
+ virtual void run();
+
+ /// shutdown the server Application
+ virtual void shutdown();
+
+ /// quit the server Application
+ virtual void quit(int status);
+};
+
+} // namespace dedicated
-#endif // __INCLUDED_SERVER_H__
+#endif // __INCLUDED_DEDICATED_H__